# SV Geometry

A collection of functions for bidimensional and tridimensional geometry.

## Installing

    pip install sv_geometry

## Submiting an issue

Go to https://github.com/ihavenonickname/sv-geometry/issues
